const fsEx = require('fs-extra');
const path = require('path');
const os = require('os');
const log4js = require('log4js');
const logger = require.main.require('log4js').getLogger(`cloudux-starter-kit ${__filename}`);
const homedir = require('os').homedir();

async function log4JsConfiguration(projectPath) {
    await isProjectPathValid(projectPath);
    try {
        let config = require('./log4jsConfig').config;
        fsEx.ensureDirSync(path.join(projectPath, 'log'));
        config.appenders.app.filename = path.join(projectPath, 'log', 'appLog.log');
        config.appenders.errorFile.filename = path.join(projectPath, 'log', 'errorLog.log');
        log4js.configure(config);
        logger.trace(`------------------------------------ Using CloudUx Starter Kit ------------------------------------`);
        logger.trace(`System information: `, os.type(), ` `, os.release(), ` `, os.platform(), ` Node Information: `, process.versions);
    } catch (err) {
        let configForLogs = require('./log4jsConfigOnlyLogs').config;
        log4js.configure(configForLogs);
        logger.debug(`Can't save logs`)
    }
}

function log4JsConfigurationBuild() {
    try {
        let config = require('./log4jsConfig').config;
        fsEx.ensureDirSync(path.join(__dirname, '..', 'log'));
        config.appenders.app.filename = path.join(__dirname, '..','log', 'appLog.log');
        config.appenders.errorFile.filename = path.join(__dirname, '..','log', 'errorLog.log');
        log4js.configure(config);
    } catch (err) {
        let configForLogs = require('./log4jsConfigOnlyLogs').config;
        log4js.configure(configForLogs);
        logger.debug(`Can't save logs err:`,err.message)
    }
}

function log4JsConfigurationSync(projectPath) {
    isProjectPathValid(projectPath);
    let config = require('./log4jsConfig').config;
    config.appenders.app.filename = path.join(projectPath, 'log', 'appLog.log');
    config.appenders.errorFile.filename = path.join(projectPath, 'log', 'errorLog.log');
    log4js.configure(config);
    logger.trace(`------------------------------------ Using CloudUx Starter Kit ------------------------------------`);
    logger.trace(`System information: `, os.type(), ` `, os.release(), ` `, os.platform(), ` Node Information: `, process.versions);
}

function isProjectPathValid(projectPath) {
    if (!fsEx.pathExistsSync(projectPath)) {
        console.error(`Invalid project path`);
        process.exit(-1);
    }
}

module.exports = {log4JsConfiguration, log4JsConfigurationBuild};
