const cliYargs = require('./cliYargs');
const publish = require('mediacentral-publish');
const publishHelper = require('../publish/publishHelper');
const sign = require('mediacentral-sign');
const signHelper = require('../sign/signHelper');
const log4jsHelper = require('../../config/log4jsHelper');

async function useCLI() {
    let options = await cliYargs.chosenOption();
    let caseToUse = await readOption(options);

    switch (caseToUse) {
        case 'Core': {
            options = await cliYargs.newProjectParameters();
            options.projectChoice = 'core';
            return options
        }
        case 'React': {
            options = await cliYargs.newProjectParameters();
            options.projectChoice = 'react';
            return options
        }
        case 'Build': {
            options = await cliYargs.buildParameters();
            let optionsObject = await publishHelper.buildOptionsToObject(options);
            await log4jsHelper.log4JsConfiguration(optionsObject.project);
            optionsObject.build = true;
            await publish(optionsObject);
            return true;
        }
        case 'BuildImage': {
            options = await cliYargs.buildParameters();
            let optionsObject = await publishHelper.buildImageOptionsToObject(options);
            await log4jsHelper.log4JsConfiguration(optionsObject.project);
            await publish(optionsObject);
            return true;
        }
        case 'Publish': {
            options = await cliYargs.publishParameters();
            let optionsObject = await publishHelper.publishOptionsToObject(options);
            await log4jsHelper.log4JsConfiguration(optionsObject.project);
            await publish(optionsObject);
            return true;
        }
        case 'Sign': {
            options = await cliYargs.signParameters();
            let optionsObject = await signHelper.signOptionsToObject(options);
            await sign(optionsObject);
            return true;
        }
        default:
            return false;
    }
}

function readOption(option) {

    if (option.Core === true)
        return 'Core';
    if (option.React !== undefined)
        return 'React';
    if (option.Build !== undefined)
        return 'Build';
    if (option.BuildImage !== undefined)
        return 'BuildImage';
    if (option.Publish !== undefined)
        return 'Publish';
    if (option.Sign !== undefined)
        return 'Sign';
    return null;
}

module.exports = {
    useCLI
};
