const yargs = require('yargs');

async function chosenOption() {
    return await yargs.usage('Usage (*-required flag): ')
        .alias('C', 'Core')
        .describe('Core', '[-n project name*] [-d project description*] [-i host ip*] [-p  port]')

        .alias('R', 'React')
        .describe('React', '[-n project name*] [-d project description*] [-i host ip*] [-p  port]')

        .alias('B', 'Build')
        .describe('Build', '[-p project path*] [-n project name*] [-o organization*] [-z appversion*] [-i appId*] [-j appSecret*]')

        .alias('I', 'BuildImage')
        .describe('BuildImage', '[-p project path*] [-n project name*] [-o organization*] [-z appversion*] [-i appId*] [-j appSecret*]')

        .alias('P', 'Publish')
        .describe('Publish', '[-p project path*] [-n project name*] [-o organization*] [-z appversion*] [-i appId*] [-j appSecret*] [-k private key path*] [-s ssh password] [-d developerId]')

        .alias('S', 'Sign')
        .describe('Sign', '[-k private key*] [-p ssh password] [-f path to file]  [-m manifest path]   [-i developer id]')

        .help()
        .argv;
}

async function newProjectParameters() {
    return await yargs.usage('Usage: ')
        .alias('n', 'project-name')
        .describe('project-name', 'project name')
        .string('project-name')

        .alias('d', 'project-description')
        .describe('project-description', 'project description')
        .string('project-description')

        .alias('i', 'project-hostIp')
        .describe('project-hostIp', 'MyApplication id for your project')
        .string('project-hostIp')

        .alias('p', 'project-port')
        .describe('project-port', 'MyApplication id for your project')
        .string('project-port')

        .alias('s', 'project-path')
        .describe('project-path', 'project path')
        .string('project-path')

        .demandOption(['n', 'd', 'i'])
        .help()
        .argv;
}

async function publishParameters() {
    const cliArgs = yargs.usage('Usage: ')
        .alias('p', 'project')
        .describe('project', 'path to a project config file')
        .string('project')

        .alias('n', 'name')
        .describe('name', 'project name (Should match project/src/project.json under identity.appName)')
        .string('name')

        .alias('z', 'appversion')
        .describe('appversion', 'appversion should match project/src/project.config.json version field')
        .string('appversion')

        .alias('d', 'developerID')
        .describe('developerID', 'developerID should match project/src/project.config.json developerID field')
        .string('developerID')

        .alias('x', 'https_proxy')
        .describe('https_proxy', 'https_proxy for docker build')
        .string('https_proxy')

        .alias('o', 'organization')
        .describe('organization', 'organization should match project/src/project.config.json organization field')
        .string('organization')

        .alias('k', 'privateKeyPath')
        .describe('privateKeyPath', 'privateKeyPath should match project/src/project.config.json privateKeyPath field')
        .string('privateKeyPath')

        .alias('i', 'appID')
        .describe('appID', 'appID should match project/src/project.config.json appID field')
        .string('appID')

        .alias('j', 'appSecret')
        .describe('appSecret', 'appSecret should match project/src/project.config.json appSecret field')
        .string('appSecret')

        .alias('s', 'password')
        .describe('password', 'password to ssh private key')
        .string('password')

        .alias('S', 'service')
        .describe('service', 'Specify if you want to publish / build feature pack for service')
        .boolean('service')

        .demandOption(['project', 'name', 'organization', 'appversion', 'appID', 'appSecret', 'privateKeyPath'])
        .help()
        .argv;
        
    const result = { 
        // Props needs to match with src/package.json / project.config.json props
        project: cliArgs.project,
        password: cliArgs.password,
        name: cliArgs.name,
        https_proxy: cliArgs.https_proxy,
        config: {
            version: cliArgs.appversion,
            developerID: cliArgs.developerID,
            organization: cliArgs.organization,
            privateKeyPath: cliArgs.privateKeyPath,
            appID: cliArgs.appID,
            appSecret: cliArgs.appSecret,
        },
        service: cliArgs.service 
    };

    Object.keys(result).forEach(key => result[key] === undefined ? delete result[key] : '');
    Object.keys(result.config).forEach(key => result.config[key] === undefined ? delete result.config[key] : '');

    return result
}

async function signParameters() {
    return await yargs.usage('Usage: ')
        .alias('k', 'key')
        .describe('key', 'path to a private key')
        .string('key')

        .alias('m', 'manifest')
        .describe('manifest', 'path to a new or existing manifest file')
        .default('manifest', './manifest.json')
        .string('manifest')

        .alias('f', 'file')
        .describe('file', 'path to a directory or file to sign')
        .default('file', '.')
        .string('file')

        .alias('p', 'password')
        .describe('password', 'password to the private key')
        .string('password')

        .alias('i', 'id')
        .describe('id', 'developers ID (assigned by Avid)')
        .string('id')
        .argv;
}

async function buildParameters() {
    const cliArgs = yargs.usage('Usage: ')
        .alias('p', 'project')
        .describe('project', 'project path')
        .string('project')

        .alias('n', 'name')
        .describe('name', 'project name (Should match project/src/project.json under identity.appName)')
        .string('name')

        .alias('z', 'appversion')
        .describe('appversion', 'appversion should match project/src/project.config.json version field')
        .string('appversion')

        .alias('d', 'developerID')
        .describe('developerID', 'developerID should match project/src/project.config.json developerID field')
        .string('developerID')

        .alias('i', 'appID')
        .describe('appID', 'appID should match project/src/project.config.json appID field')
        .string('appID')

        .alias('j', 'appSecret')
        .describe('appSecret', 'appSecret should match project/src/project.config.json appSecret field')
        .string('appSecret')

        .alias('x', 'https_proxy')
        .describe('https_proxy', 'https_proxy for docker build')
        .string('https_proxy')

        .alias('o', 'organization')
        .describe('organization', 'organization should match project/src/project.config.json organization field')
        .string('organization')

        .alias('S', 'service')
        .describe('service', 'Specify if you want to publish / build feature pack for service')
        .boolean('service')

        .demandOption(['project', 'name', 'organization', 'appversion', 'appID', 'appSecret'])
        .help()
        .argv;
        
    const result = { 
        // Props needs to match with src/package.json / project.config.json props
        project: cliArgs.project,
        name: cliArgs.name,
        https_proxy: cliArgs.https_proxy,
        config: {
            version: cliArgs.appversion,
            developerID: cliArgs.developerID,
            organization: cliArgs.organization,
            appID: cliArgs.appID,
            appSecret: cliArgs.appSecret,
        },
        build: cliArgs.build,
        service: cliArgs.service 
    };

    Object.keys(result).forEach(key => result[key] === undefined ? delete result[key] : '');
    Object.keys(result.config).forEach(key => result.config[key] === undefined ? delete result.config[key] : '');

    return result
}

module.exports = {
    chosenOption,
    newProjectParameters,
    publishParameters,
    buildParameters,
    signParameters,
};
